@@ -1,4 +1,5 @@
 /* Copyright 2010  Anton Kreuzkamp <akreuzkamp@web.de>
+ * Copyright 2020  Alexander Lohnau <alexander.lohnau@gmx.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,27 +19,24 @@
  */
 
 #include "charrunner.h"
+#include "config_keys.h"
 
 // KF
 #include <KRunner/QueryMatch>
 #include <KLocalizedString>
+// Qt
+#include <QGuiApplication>
+#include <QDebug>
+#include <QClipboard>
 
-
-//Names of config-entries
-static const char CONFIG_TRIGGERWORD[] = "triggerWord";
-static const char CONFIG_ALIASES[] = "aliases";
-static const char CONFIG_CODES[] = "codes";
-
-
-CharacterRunner::CharacterRunner( QObject* parent, const QVariantList &args )
+CharacterRunner::CharacterRunner(QObject *parent, const QVariantList &args)
     : Plasma::AbstractRunner(parent, args)
 {
     Q_UNUSED(args)
-    setObjectName(QLatin1String( "CharacterRunner" ));
+    setObjectName(QStringLiteral("CharacterRunner"));
     setIgnoredTypes(Plasma::RunnerContext::Directory | Plasma::RunnerContext::File |
-                         Plasma::RunnerContext::NetworkLocation | Plasma::RunnerContext::Executable |
-                         Plasma::RunnerContext::ShellCommand);
-    reloadConfiguration();
+        Plasma::RunnerContext::NetworkLocation | Plasma::RunnerContext::Executable |
+        Plasma::RunnerContext::ShellCommand);
 }
 
 CharacterRunner::~CharacterRunner()
@@ -47,55 +45,58 @@ CharacterRunner::~CharacterRunner()
 
 void CharacterRunner::reloadConfiguration()
 {
-  KConfigGroup grp = config(); //Create config-object
 
-  m_triggerWord = grp.readEntry(CONFIG_TRIGGERWORD, "#"); //read out the triggerword
-  m_aliases = grp.readEntry(CONFIG_ALIASES, QStringList());
-  m_codes = grp.readEntry(CONFIG_CODES, QStringList());
-  addSyntax(Plasma::RunnerSyntax(m_triggerWord + QLatin1String( ":q:" ),
-                                 i18n("Creates Characters from :q: if it is a hexadecimal code or defined alias.")));
+    const KConfigGroup grp = config();
+    m_triggerWord = grp.readEntry(CONFIG_TRIGGERWORD, DEFAULT_TRIGGERWORD.toString());
+    m_aliases = grp.readEntry(CONFIG_ALIASES, QStringList());
+    m_codes = grp.readEntry(CONFIG_CODES, QStringList());
+    if (m_codes.size() != m_aliases.size()) {
+        m_aliases.clear();
+        m_codes.clear();
+        qWarning() << "Config entries for alias list and code list have different sizes, ignoring all.";
+    }
+
+    addSyntax(Plasma::RunnerSyntax(m_triggerWord + QStringLiteral(":q:"),
+                                   i18n("Creates Characters from :q: if it is a hexadecimal code or defined alias.")));
 }
 
 void CharacterRunner::match(Plasma::RunnerContext &context)
 {
-    QString term = context.query();
+    QString term = context.query().remove(QLatin1Char(' '));
 
-    term = term.replace(QLatin1Char( ' ' ), QLatin1String( "" )); //remove blanks
-    if (term.length() < 2) //ignore too short queries
-    {
+    if (term.length() < 2 || !term.startsWith(m_triggerWord) || !context.isValid()) {
         return;
     }
-    if (!term.startsWith(m_triggerWord)) //ignore queries without the triggerword
-    {
-      return;
-    }
+
     term = term.remove(0, m_triggerWord.length()); //remove the triggerword
 
-    if (m_aliases.contains(term)) //replace aliases by their hex.-code
-    {
-      term = m_codes[m_aliases.indexOf(term)];
+    //replace aliases by their hex.-code
+    if (m_aliases.contains(term)) {
+        term = m_codes[m_aliases.indexOf(term)];
     }
 
-    bool ok; //checkvariable
+    bool ok;
     int hex = term.toInt(&ok, 16); //convert query into int
-    if (!ok) //check if conversion was successful
-    {
-      return;
+    if (!ok) {
+        return;
     }
 
     //make special character out of the hex.-code
     const QString specChar = QChar(hex);
-
-    //create match
     Plasma::QueryMatch match(this);
-    match.setType(Plasma::QueryMatch::InformationalMatch);
+    match.setType(Plasma::QueryMatch::ExactMatch);
     match.setIconName(QStringLiteral("accessories-character-map"));
     match.setText(specChar);
     match.setData(specChar);
-    match.setId(QString());
     context.addMatch(match);
 }
 
+void CharacterRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
+{
+    Q_UNUSED(context)
+    QGuiApplication::clipboard()->setText(match.data().toString());
+}
+
 K_EXPORT_PLASMA_RUNNER(CharacterRunner, CharacterRunner)
 
 #include "charrunner.moc"
